@@ -34,15 +34,17 @@ def create_app(name: str) -> Flask:
     """
 
     app = Flask(name)
-
     with app.app_context():
         loader.load_config(app)
         loader.load_extensions(app)
         loader.load_models(app)
+        loader.load_urls(app)
         loader.load_blueprints(app)
+        loader.load_middlewares(app)
         loader.load_apis(app)
         loader.load_commands(app)
         loader.load_services(app)
         loader.load_docs(app)
+        loader.load_apps(app)
 
     return app
