@@ -1,9 +1,11 @@
 from datetime import timedelta
-
+from os import path
 
 class Development(object):
     SECRET_KEY = "Your secret key!"
-    SQLALCHEMY_DATABASE_URI = "sqlite:///db.sqlite"
+    SQLALCHEMY_DATABASE_URI = "sqlite:///" + path.join(
+        path.dirname(__file__), "db.sqlite"
+    )
     SQLALCHEMY_TRACK_MODIFICATIONS = False
     JWT_SECRET_KEY = "JWT secret key!"
     JWT_ACCESS_TOKEN_EXPIRES = timedelta(days=7)
@@ -12,6 +14,9 @@ class Development(object):
     APISPEC_TITLE = "API Docs"
     APISPEC_SWAGGER_UI_URL = "/docs"
     DEBUG = True
+    {% if main_app -%}
+        APPS = []
+    {%- endif %}
     EXTENSIONS = [
         "extensions.sqlalchemy",
         "extensions.marshmallow",
@@ -24,10 +29,15 @@ class Development(object):
     COMMANDS = [
         "zemfrog.commands.api",
         "zemfrog.commands.blueprint",
+        "zemfrog.commands.middleware",
         "zemfrog.commands.schema",
         "zemfrog.commands.command",
+        {% if main_app -%}
+            "zemfrog.commands.app"
+        {%- endif %}
     ]
     BLUEPRINTS = ["auth"]
+    MIDDLEWARES = []
     APIS = []
     API_DOCS = True
     CREATE_DB = True
